Struct Dfltier
#[repr(transparent)]pub struct Dfltier(pub u32);Expand description
This register is used for allowing or not the events to generate an interrupt.
Tuple Fields
0: u32Implementations
impl Dfltier
impl Dfltier
pub const fn fthie(&self) -> bool
pub const fn fthie(&self) -> bool
RXFIFO threshold interrupt enable Set and cleared by software. - 0: RXFIFO threshold interrupt disabled - 1: RXFIFO threshold interrupt enabled.
pub const fn set_fthie(&mut self, val: bool)
pub const fn set_fthie(&mut self, val: bool)
RXFIFO threshold interrupt enable Set and cleared by software. - 0: RXFIFO threshold interrupt disabled - 1: RXFIFO threshold interrupt enabled.
pub const fn dovrie(&self) -> bool
pub const fn dovrie(&self) -> bool
Data overflow interrupt enable Set and cleared by software. - 0: Data overflow interrupt disabled - 1: Data overflow interrupt enabled.
pub const fn set_dovrie(&mut self, val: bool)
pub const fn set_dovrie(&mut self, val: bool)
Data overflow interrupt enable Set and cleared by software. - 0: Data overflow interrupt disabled - 1: Data overflow interrupt enabled.
pub const fn ssdrie(&self) -> bool
pub const fn ssdrie(&self) -> bool
Snapshot data ready interrupt enable Set and cleared by software. - 0: Snapshot data ready interrupt disabled - 1: Snapshot data ready interrupt enabled.
pub const fn set_ssdrie(&mut self, val: bool)
pub const fn set_ssdrie(&mut self, val: bool)
Snapshot data ready interrupt enable Set and cleared by software. - 0: Snapshot data ready interrupt disabled - 1: Snapshot data ready interrupt enabled.
pub const fn oldie(&self) -> bool
pub const fn oldie(&self) -> bool
Out-of Limit interrupt enable Set and cleared by software. - 0: OLD event interrupt disabled - 1: OLD event interrupt enabled.
pub const fn set_oldie(&mut self, val: bool)
pub const fn set_oldie(&mut self, val: bool)
Out-of Limit interrupt enable Set and cleared by software. - 0: OLD event interrupt disabled - 1: OLD event interrupt enabled.
pub const fn ssovrie(&self) -> bool
pub const fn ssovrie(&self) -> bool
Snapshot overrun interrupt enable Set and cleared by software. - 0: Snapshot overrun interrupt disabled - 1: Snapshot overrun interrupt enabled.
pub const fn set_ssovrie(&mut self, val: bool)
pub const fn set_ssovrie(&mut self, val: bool)
Snapshot overrun interrupt enable Set and cleared by software. - 0: Snapshot overrun interrupt disabled - 1: Snapshot overrun interrupt enabled.
pub const fn scdie(&self) -> bool
pub const fn scdie(&self) -> bool
Short-Circuit Detector interrupt enable Set and cleared by software. - 0: SCD interrupt disabled - 1: SCD interrupt enabled.
pub const fn set_scdie(&mut self, val: bool)
pub const fn set_scdie(&mut self, val: bool)
Short-Circuit Detector interrupt enable Set and cleared by software. - 0: SCD interrupt disabled - 1: SCD interrupt enabled.
pub const fn satie(&self) -> bool
pub const fn satie(&self) -> bool
Saturation detection interrupt enable Set and cleared by software. - 0: Saturation interrupt disabled - 1: Saturation interrupt enabled.
pub const fn set_satie(&mut self, val: bool)
pub const fn set_satie(&mut self, val: bool)
Saturation detection interrupt enable Set and cleared by software. - 0: Saturation interrupt disabled - 1: Saturation interrupt enabled.
pub const fn ckabie(&self) -> bool
pub const fn ckabie(&self) -> bool
Clock absence detection interrupt enable Set and cleared by software. - 0: Clock absence interrupt disabled - 1: Clock absence interrupt enabled.
pub const fn set_ckabie(&mut self, val: bool)
pub const fn set_ckabie(&mut self, val: bool)
Clock absence detection interrupt enable Set and cleared by software. - 0: Clock absence interrupt disabled - 1: Clock absence interrupt enabled.
pub const fn rfovrie(&self) -> bool
pub const fn rfovrie(&self) -> bool
Reshape Filter Overrun interrupt enable Set and cleared by software. - 0: Reshape filter overrun interrupt disabled - 1: Reshape filter overrun interrupt enabled.
pub const fn set_rfovrie(&mut self, val: bool)
pub const fn set_rfovrie(&mut self, val: bool)
Reshape Filter Overrun interrupt enable Set and cleared by software. - 0: Reshape filter overrun interrupt disabled - 1: Reshape filter overrun interrupt enabled.