Struct Oldthlr
#[repr(transparent)]pub struct Oldthlr(pub u32);Expand description
This register is used for the adjustment of the Out-off Limit low threshold.
Tuple Fields
0: u32Implementations
impl Oldthlr
impl Oldthlr
pub const fn oldthl(&self) -> u32
pub const fn oldthl(&self) -> u32
OLD Low Threshold Value Set and cleared by software. OLDTHL represents a 26-bit signed value. The real threshold compared to the signal provided by the filter is OLDTHL. This field can be write-protected, please refer to Section 1.4.15: Register protection for details.
pub const fn set_oldthl(&mut self, val: u32)
pub const fn set_oldthl(&mut self, val: u32)
OLD Low Threshold Value Set and cleared by software. OLDTHL represents a 26-bit signed value. The real threshold compared to the signal provided by the filter is OLDTHL. This field can be write-protected, please refer to Section 1.4.15: Register protection for details.